[llvm-commits] [llvm] r64600 - /llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp
Nicolas Geoffray
nicolas.geoffray at lip6.fr
Sun Feb 15 12:49:23 PST 2009
Author: geoffray
Date: Sun Feb 15 14:49:23 2009
New Revision: 64600
URL: http://llvm.org/viewvc/llvm-project?rev=64600&view=rev
Log:
On 64bit we may have a personality function which requires 64 bits to
be encoded.
Modified:
llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp
Modified: llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp?rev=64600&r1=64599&r2=64600&view=diff
==============================================================================
--- llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp (original)
+++ llvm/trunk/lib/ExecutionEngine/JIT/JITDwarfEmitter.cpp Sun Feb 15 14:49:23 2009
@@ -519,14 +519,20 @@
MCE->emitByte(RI->getDwarfRegNum(RI->getRARegister(), true));
if (Personality) {
- MCE->emitULEB128Bytes(7);
+ // Augmentation Size: 3 small ULEBs of one byte each, and the personality
+ // function which size is PointerSize.
+ MCE->emitULEB128Bytes(3 + PointerSize);
- // Direct encoding, because we use the function pointer. Not relative,
- // because the current PC value may be bigger than the personality
- // function pointer.
- MCE->emitByte(dwarf::DW_EH_PE_sdata4);
-
- MCE->emitInt32(((intptr_t)Jit.getPointerToGlobal(Personality)));
+ // We set the encoding of the personality as direct encoding because we use
+ // the function pointer. The encoding is not relative because the current
+ // PC value may be bigger than the personality function pointer.
+ if (PointerSize == 4) {
+ MCE->emitByte(dwarf::DW_EH_PE_sdata4);
+ MCE->emitInt32(((intptr_t)Jit.getPointerToGlobal(Personality)));
+ } else {
+ MCE->emitByte(dwarf::DW_EH_PE_sdata8);
+ MCE->emitInt64(((intptr_t)Jit.getPointerToGlobal(Personality)));
+ }
MCE->emitULEB128Bytes(dwarf::DW_EH_PE_pcrel | dwarf::DW_EH_PE_sdata4);
MCE->emitULEB128Bytes(dwarf::DW_EH_PE_pcrel | dwarf::DW_EH_PE_sdata4);
More information about the llvm-commits
mailing list